@@ -84,14 +84,6 @@ def evaluateExpression(inputExpression):
     return evaluatePostfix(shunting_yard(inputExpression))
 
 
-
-
-
-
-
-
-
-
 def teach_me_trig():
     print("welcome to the trig basics course!")
     time.sleep(0.5)
@@ -366,15 +358,28 @@ def clear():
 
 
     
-def add(a, b):
-    return a+b
-def subtract(a, b):
-    return a-b
-def multiply(a, b):
-    return a*b
-def divide(a, b):
-    return a/b
-def power(a, b):    #
+def add(*args):
+    return sum(args)
+def subtract(a, *args):
+    return a - sum(args)
+def multiply(*args):
+    x = 1
+    y = 0
+    while y < len(args):
+        x = x*args[y]
+        y+=1
+    return x
+def divide(a, *args):
+    return a / listMultiply(args)
+def listMultiply(List):
+    x = 1
+    y = 0
+    while y < len(List):
+        x = x*List[y]
+        y+=1
+    return x
+def power(a, *args):    
+    b = mult(args)
     x = a**(b)
     if b < 1:
         return root(a, 1/b)
@@ -572,7 +577,11 @@ def divisCheck(num, num2):
         return True
     else:
         return False
-    
+def summate(n, a, b):
+    return sum(nthRange(n, a, b))
+def product(n, a, b):
+    return listMultiply(nthRange(n, a, b))
+
 def PercentagetoDecimal(percentage):
     return p / 100
 def PerToFrac(p):
@@ -772,7 +781,7 @@ def nthRange(a, b, c):
     if int(b) > int(c):
         while int(c) < int(b)+1:
             x = a.replace("n", c)
-            y = evaluateExpression(x)
+            y = int(evaluateExpression(x))
             ls.append(y)
             c = int(c)
             c=int(c)+1
@@ -780,12 +789,12 @@ def nthRange(a, b, c):
     elif int(c) > int(b):
         while int(b) < int(c)+1:
             x = a.replace("n", b)
-            y = evaluateExpression(x)
+            y = int(evaluateExpression(x))
             ls.append(y)
             b = int(b)
             b=int(b)+1
             b = str(b)
-    return ls
+    return list(ls)
 def nthTable(a, b, c):
     ls = []
     a = str(a)
@@ -847,7 +856,6 @@ def average(*argv):
     total = np.sum(list(argv))
     length = len(argv)
     return total / length
-
 def consecutiveIntCalc(x):
     a = (x/3)-1
     b = x/3
@@ -961,20 +969,24 @@ def constTable():
     thing = tabulate(conlist, headers = headers)
     print(thing)
 
-def graph(graph_func, lrange=-10, urange=10, graph_points=100, graph_title=None):
-    x = np.linspace(lrange, urange, graph_points)
-    y = evaluateExpression(graph_func)
-    plt.title(graph_title)
-    plt.plot(x,y) 
-    plt.show()
-def exp_graph(*argv):
-    z = 0
-    argv = list(argv)
-    while z < len(argv):
-        x = np.linspace(lrange, urange, graph_points)
-        y = evaluateExpression(str(argv[z]))
-        plt.title(graph_title)
+def graph(*args, lrangex=-10, urangex=10, lrangey=-10, urangey=10, graph_points=100, gridset=True, scaling=True, graph_title=None, xtitle=None, ytitle=None):
+    i = 0
+    x = np.linspace(lrangex, urangex, graph_points)
+    while i < len(args):
+        if type(eval(args[i])) == np.ndarray:
+            y = eval(args[i])
+        else:
+            pass
         plt.plot(x,y)
-        z += 1
+        i+=1
+    plt.title(graph_title)
+    plt.xlabel(xtitle,fontsize=20)
+    plt.ylabel(ytitle,fontsize=20)
+    plt.autoscale(enable=scaling)
+    plt.grid(gridset)
+    if lrangex or urangex != False:
+        plt.xlim([lrangex,urangex])
+    if lrangey or urangey != False:
+        plt.ylim([lrangey,urangey])
     plt.show()
 
