@@ -358,15 +358,28 @@ def clear():
 
 
     
-def add(a, b):
-    return a+b
+def add(*args):
+    return sum(args)
 def subtract(a, b):
     return a-b
-def multiply(a, b):
-    return a*b
+def multiply(*args):
+    x = 1
+    y = 0
+    while y < len(args):
+        x = x*args[y]
+        y+=1
+    return x
 def divide(a, b):
     return a/b
-def power(a, b):    #
+def listMultiply(list):
+    x = 1
+    y = 0
+    while y < len(lis):
+        x = x*lis[y]
+        y+=1
+    return x
+def power(a, *args):    
+    b = mult(args)
     x = a**(b)
     if b < 1:
         return root(a, 1/b)
@@ -968,6 +981,8 @@ def graph(*args, lrangex=-10, urangex=10, lrangey=-10, urangey=10, graph_points=
     plt.ylabel(ytitle,fontsize=20)
     plt.autoscale(enable=scaling)
     plt.grid(gridset)
-    plt.xlim([lrangex,urangex])
-    plt.ylim([lrangey,urangey])
+    if lrangex or urangex != False:
+        plt.xlim([lrangex,urangex])
+    if lrangey or urangey != False:
+        plt.ylim([lrangey,urangey])
     plt.show()
